API reference for the bicycleparameters Package
===============================================

.. toctree::

   api/bicycle.rst
   api/com.rst
   api/geometry.rst
   api/inertia.rst
   api/io.rst
   api/main.rst
   api/models.rst
   api/parameter_sets.rst
   api/period.rst
   api/plot.rst
   api/rider.rst
   api/tables.rst
